==> owncloud-5.0.9.tgz: owncloud/apps/calendar/l10n/ta_LK.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "எல்லா நாட்காட்டிகளும் முற்றாக இடைமாற்றுநினைவகம் ஆகவில்லை",
"Everything seems to be completely cached" => "எல்லாம் முற்றாக இடைமாற்றுநினைவகம் ஆகியதாக தென்படுகிறது",
"No calendars found." => "நாட்காட்டிகள் எதுவும் கண்டறியப்படவில்லை",
"No events found." => "நிகழ்வுகள் எதுவும் கண்டறியப்படவில்லை",
"Wrong calendar" => "பிழையான நாட்காட்டி",
"You do not have the permissions to edit this event." => "இந்த நிகழ்வை தொகுப்பதற்கு உங்களுக்கு அனுமதி இல்லை ",
"The file contained either no events or all events are already saved in your calendar." => "கோப்பு உங்களுடைய நாட்காட்டியில் ஒரு நிகழ்வும் இல்லாததையோ அல்லது ஏற்கனவே எல்லா நிகழ்வும் சேமித்ததையோ கொண்டுள்ளது. ",
"events has been saved in the new calendar" => "புதிய நாட்காட்டியில் நிகழ்வுகள் சேமிக்கப்பட்டது",
"Import failed" => "இறக்குமதி தோல்வியுற்றது",
"events has been saved in your calendar" => "உங்களுடைய நாட்காட்டியில் நிகழ்வுகள் சேமிக்கப்பட்டது",
"New Timezone:" => "புதிய நேர மண்டலம்",
"Timezone changed" => "நேர மண்டலம் மாறியுள்ளது",
"Invalid request" => "செல்லுபடியற்ற வேண்டுகோள்",
"Calendar" => "நாட்காட்டி",
"Deletion failed" => "நீக்கம் தோல்வியடைந்தது",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"user" => "பயனாளர்",
"group" => "குழு",
"Editable" => "தொகுக்கக்கூடியது",
"Shareable" => "பகிரக்கூடியது",
"Deletable" => "அழிக்கக்கூடியது",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "ddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "ஞாயிற்றுக்கிழமை",
"Monday" => "திங்கட்கிழமை",
"Tuesday" => "செவ்வாய்க்கிழமை",
"Wednesday" => "புதன்கிழமை",
"Thursday" => "வியாழக்கிழமை",
"Friday" => "வெள்ளிக்கிழமை",
"Saturday" => "சனிக்கிழமை",
"Sun." => "ஞாயிறு",
"Mon." => "திங்கள்",
"Tue." => "செவ்வாய்",
"Wed." => "புதன்",
"Thu." => "வியாழன்",
"Fri." => "வெள்ளி",
"Sat." => "சனி",
"January" => "தை",
"February" => "மாசி",
"March" => "பங்குனி",
"April" => "சித்திரை",
"May" => "வைகாசி",
"June" => "ஆனி",
"July" => "ஆடி",
"August" => "ஆவணி",
"September" => "புரட்டாசி",
"October" => "ஐப்பசி",
"November" => "கார்த்திகை",
"December" => "மார்கழி",
"Jan." => "தை",
"Feb." => "மாசி",
"Mar." => "பங்குனி",
"Apr." => "சித்திரை",
"May." => "வைகாசி",
"Jun." => "ஆனி",
"Jul." => "ஆடி",
"Aug." => "ஆவணி",
"Sep." => "புரட்டாதி",
"Oct." => "ஐப்பசி",
"Nov." => "கார்த்திகை",
"Dec." => "மார்கழி",
"All day" => "அனைத்து நாட்களும்",
"New Calendar" => "புதிய நாட்காட்டி",
"Missing or invalid fields" => "விடுபட்ட அல்லது செல்லுபடியற்ற புலங்கள்",
"Title" => "தலைப்பு",
"From Date" => "திகதியிலிருந்து",
"From Time" => "நேரத்திலிருந்து",
"To Date" => "திகதி வரை",
"To Time" => "நேரம் வரை",
"The event ends before it starts" => "அது தொடங்குவதற்கு முன்பு நிகழ்வு முடிந்துவிடும்",
"There was a database fail" => "தரவுத்தள பிழை ஒன்று உள்ளது",
"Birthday" => "பிறந்த நாள்",
"Business" => "வியாபாரம்",
"Call" => "அழை",
"Clients" => "வாடிக்கையாளர்கள்",
"Deliverer" => "விநியோகிப்பவர்",
"Holidays" => "விடுமுறைகள்",
"Ideas" => "எண்ணங்கள்",
"Journey" => "பயணம்",
"Jubilee" => "50 ஆவது வருட விழா",
"Meeting" => "கூட்டம்",
"Other" => "மற்றவை",
"Personal" => "தனிப்பட்ட",
"Projects" => "செயல் திட்டங்கள்",
"Questions" => "கேள்விகள்",
"Work" => "வேலை",
"by" => "மூலம்",
"unnamed" => "பெயரிடப்படவில்லை",
"You do not have the permissions to update this calendar." => "இந்த நாட்காட்டியை இற்​றைப்படுத்துவதற்கு உங்களுக்கு அனுமதி இல்லை ",
"You do not have the permissions to delete this calendar." => "இந்த நாட்காட்டியை நீக்குவதற்கு உங்களுக்கு அனுமதி இல்லை ",
"You do not have the permissions to add to this calendar." => "இந்த நாட்காட்டியை சேர்ப்பதற்கு உங்களுக்கு அனுமதி இல்லை",
"You do not have the permissions to add events to this calendar." => "இந்த நாட்காட்டிக்கு நிகழ்வுகளை சேர்க்க உங்களுக்கு அனுமதி இல்லை",
"You do not have the permissions to delete this event." => "இந்த நிகழ்வை அழிப்பதற்கு உங்களுக்கு அனுமதி இல்லை ",
"Does not repeat" => "மீண்டும் இல்லாமல்",
"Daily" => "ஒவ்வொரு நாளும்",
"Weekly" => "வாரந்தோறும்",
"Every Weekday" => "ஒவ்வொரு வாரநாளும்",
"Bi-Weekly" => "இரு வாரத்திற்கு ஒரு முறை",
"Monthly" => "மாதந்தோரும்",
"Yearly" => "வருடந்தோறும்",
"never" => "ஒருபோதும்",
"by occurrences" => "நிகழ்வுகள் மூலம்",
"by date" => "திகதியினால்",
"by monthday" => "மாதநாளில்",
"by weekday" => "வாரநாளில்",
"events week of month" => "மாதத்தின் நிகழ்வு வாரங்கள்",
"first" => "முதலாவது",
"second" => "இரண்டாவது",
"third" => "மூன்றாவது",
"fourth" => "நான்காவது",
"fifth" => "ஐந்தாவது",
"last" => "இறுதி",
"by events date" => "நிகழ்வை கொண்ட திகதி",
"by yearday(s)" => "வருட நாள் (கள்) மூலம்",
"by weeknumber(s)" => "வார எண்ணிக்கை (கள்) மூலம்",
"by day and month" => "நாள் மற்றும் மாதம் மூலம்",
"Date" => "திகதி",
"Cal." => "Cal.",
"Week" => "வாரம்",
"Month" => "மாதம்",
"List" => "பட்டியல்",
"Today" => "இன்று",
"Settings" => "அமைப்புகள்",
"Your calendars" => "உங்களுடைய நாட்காட்டிகள்",
"CalDav Link" => "CalDav இணைப்பு",
"Share Calendar" => "நாட்காட்டியை பகிர்க",
"Download" => "பதிவிறக்குக",
"Edit" => "தொகுக்க",
"Delete" => "அழிக்க",
"New calendar" => "புதிய நாட்காட்டி",
"Edit calendar" => "நாட்காட்டியை தொகுக்க",
"Displayname" => "காட்சி பெயர்",
"Active" => "இயங்கும்",
"Calendar color" => "நாட்காட்டி நிறம்",
"Save" => "சேமிக்க",
"Submit" => "சமர்ப்பிக்குக",
"Cancel" => "இரத்து செய்க",
"Edit an event" => "ஒரு நிகழ்வை தொகுக்க",
"Export" => "ஏற்றுமதி",
"Eventinfo" => "நிகழ்வு தகவல்",
"Repeating" => "மீண்டும்",
"Alarm" => "எச்சரிக்கை",
"Attendees" => "பங்கேற்பாளர்கள்",
"Share" => "பகிர்வு",
"Title of the Event" => "நிகழ்வின் தலைப்பு",
"Category" => "வகை",
"Separate categories with commas" => "வகைகளை காற்புள்ளியினால் வேறுப்படுத்துக",
"Edit categories" => "வகைகளை தொகுக்க",
"All Day Event" => "அனைத்து நாள் நிகழ்வு",
"From" => "இருந்து ",
"To" => "இற்கு",
"Advanced options" => "மேலதிக தெரிவுகள்",
"Location" => "இடம்",
"Location of the Event" => "நிகழ்வு நடைபெறும் இடம்",
"Description" => "விவரணம்",
"Description of the Event" => "நிகழ்வு பற்றிய விவரணம்",
"Repeat" => "மீண்டும்",
"Advanced" => "உயர்ந்த",
"Select weekdays" => "வாரநாட்களை தெரிவுசெய்க",
"Select days" => "நாட்களை தெரிவுசெய்க",
"and the events day of year." => "வருடத்தில் நிகழ்வை கொண்ட நாட்கள்",
"and the events day of month." => "மாதத்தில் நிகழ்வை கொண்ட நாட்கள்",
"Select months" => "மாதங்களை தெரிவுசெய்க",
"Select weeks" => "வாரங்களை தெரிவுசெய்க",
"and the events week of year." => "வருடத்தில் நிகழ்வை கொண்ட வாரங்கள்",
"Interval" => "இடைவேளை",
"End" => "இறுதி",
"occurrences" => "நிகழ்ச்சி",
"create a new calendar" => "புதிய நாட்காட்டி ஒன்றை உருவாக்குக",
"Import a calendar file" => "நாட்காட்டி கோப்பொன்றை இறக்குமதி செய்க",
"Please choose a calendar" => "தயவுசெய்து ஒரு நாட்காட்டியை தெரிவுசெய்க",
"Name of new calendar" => "புதிய நாட்காட்டியின் பெயர்",
"Take an available name!" => "கிடைக்கக்கூடிய பெயரொன்றை எடுக்க!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "இந்த பெயரைக்கொண்ட நாட்காட்டி ஏற்கனவே உள்ளது.  நீங்கள் இதனை தொடர்ந்தால், நாட்காட்டிகள் ஒன்றிணைக்கப்படலாம். ",
"Remove all events from the selected calendar" => "தெரிவுசெய்யப்பட்ட நாட்காட்டியில் உள்ள எல்லா நிகழ்வுகளையும் அகற்றுக ",
"Import" => "இறக்குமதி",
"Close Dialog" => "Dialog மூடுக",
"Create a new event" => "புதிய நிகழ்வை உருவாக்க",
"Share with:" => "இடையில் பகிர்க:",
"Shared with" => "உடன் பகிர்க",
"Unshare" => "பகிரமுடியாது",
"Nobody" => "ஒருவருமில்லை",
"Shared via calendar" => "நாட்காட்டியினூடாக பகிர்க",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "குறிப்பு: நாட்காட்டியினூடாக பகிரப்பட்ட நிகழ்வுகளின் செயல்கள் முழு நாட்காட்டி பகிர்வையும் பாதிக்கும். ",
"View an event" => "ஒரு நிகழ்வை பார்வையிடவும்",
"No categories selected" => "வகைகள் தெரிவுசெய்யப்படவில்லை",
"of" => "உடைய",
"at" => "இல்",
"General" => "பொதுவானது",
"Timezone" => "நேர மண்டலம்",
"Update timezone automatically" => "நேர மண்டலத்தை தன்னிச்சையாக இற்றைப்படுத்துக",
"Time format" => "நேர வடிவமைப்பு",
"24h" => "24ஆம்",
"12h" => "12ஆம்",
"Start week on" => "தொடங்கும் வாரம்",
"Cache" => "இடைமாற்றுநினைவகம்",
"Clear cache for repeating events" => "மீள் நிகழ்ச்சிக்கான இடைமாற்றுநினைவகத்தை சுத்தப்படுத்துக",
"URLs" => "URLs",
"Calendar CalDAV syncing addresses" => "CalDAV  நாட்காட்டியின் ஒத்திசை முகவரிகள்",
"more info" => "மேலதிக தகவல்",
"Primary address (Kontact et al)" => "முதன்மை முகவரி (Kontact et al)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "வாசிக்க மட்டும் கூடிய iCalendar இணைப்பு (கள்)"
);

==> owncloud-7.0.4.tgz: owncloud/apps/calendar/l10n/ta_LK.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "எல்லா நாட்காட்டிகளும் முற்றாக இடைமாற்றுநினைவகம் ஆகவில்லை",
"Everything seems to be completely cached" => "எல்லாம் முற்றாக இடைமாற்றுநினைவகம் ஆகியதாக தென்படுகிறது",
"No calendars found." => "நாட்காட்டிகள் எதுவும் கண்டறியப்படவில்லை",
"No events found." => "நிகழ்வுகள் எதுவும் கண்டறியப்படவில்லை",
"Wrong calendar" => "பிழையான நாட்காட்டி",
"You do not have the permissions to edit this event." => "இந்த நிகழ்வை தொகுப்பதற்கு உங்களுக்கு அனுமதி இல்லை ",
"The file contained either no events or all events are already saved in your calendar." => "கோப்பு உங்களுடைய நாட்காட்டியில் ஒரு நிகழ்வும் இல்லாததையோ அல்லது ஏற்கனவே எல்லா நிகழ்வும் சேமித்ததையோ கொண்டுள்ளது. ",
"Import failed" => "இறக்குமதி தோல்வியுற்றது",
"New Timezone:" => "புதிய நேர மண்டலம்",
"Timezone changed" => "நேர மண்டலம் மாறியுள்ளது",
"Invalid request" => "செல்லுபடியற்ற வேண்டுகோள்",
"Calendar" => "நாட்காட்டி",
"Deletion failed" => "நீக்கம் தோல்வியடைந்தது",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"group" => "குழு",
"can edit" => "தொகுக்க முடியும்",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "ddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "ஞாயிற்றுக்கிழமை",
"Monday" => "திங்கட்கிழமை",
"Tuesday" => "செவ்வாய்க்கிழமை",
"Wednesday" => "புதன்கிழமை",
"Thursday" => "வியாழக்கிழமை",
"Friday" => "வெள்ளிக்கிழமை",
"Saturday" => "சனிக்கிழமை",
"Sun." => "ஞாயிறு",
"Mon." => "திங்கள்",
"Tue." => "செவ்வாய்",
"Wed." => "புதன்",
"Thu." => "வியாழன்",
"Fri." => "வெள்ளி",
"Sat." => "சனி",
"January" => "தை",
"February" => "மாசி",
"March" => "பங்குனி",
"April" => "சித்திரை",
"May" => "வைகாசி",
"June" => "ஆனி",
"July" => "ஆடி",
"August" => "ஆவணி",
"September" => "புரட்டாசி",
"October" => "ஐப்பசி",
"November" => "கார்த்திகை",
"December" => "மார்கழி",
"Jan." => "தை",
"Feb." => "மாசி",
"Mar." => "பங்குனி",
"Apr." => "சித்திரை",
"May." => "வைகாசி",
"Jun." => "ஆனி",
"Jul." => "ஆடி",
"Aug." => "ஆவணி",
"Sep." => "புரட்டாதி",
"Oct." => "ஐப்பசி",
"Nov." => "கார்த்திகை",
"Dec." => "மார்கழி",
"All day" => "அனைத்து நாட்களும்",
"New Calendar" => "புதிய நாட்காட்டி",
"Missing or invalid fields" => "விடுபட்ட அல்லது செல்லுபடியற்ற புலங்கள்",
"Title" => "தலைப்பு",
"From Date" => "திகதியிலிருந்து",
"From Time" => "நேரத்திலிருந்து",
"To Date" => "திகதி வரை",
"To Time" => "நேரம் வரை",
"The event ends before it starts" => "அது தொடங்குவதற்கு முன்பு நிகழ்வு முடிந்துவிடும்",
"There was a database fail" => "தரவுத்தள பிழை ஒன்று உள்ளது",
"Birthday" => "பிறந்த நாள்",
"Business" => "வியாபாரம்",
"Call" => "அழை",
"Clients" => "வாடிக்கையாளர்கள்",
"Deliverer" => "விநியோகிப்பவர்",
"Holidays" => "விடுமுறைகள்",
"Ideas" => "எண்ணங்கள்",
"Journey" => "பயணம்",
"Jubilee" => "50 ஆவது வருட விழா",
"Meeting" => "கூட்டம்",
"Other" => "மற்றவை",
"Personal" => "தனிப்பட்ட",
"Projects" => "செயல் திட்டங்கள்",
"Questions" => "கேள்விகள்",
"Work" => "வேலை",
"by" => "மூலம்",
"unnamed" => "பெயரிடப்படவில்லை",
"You do not have the permissions to update this calendar." => "இந்த நாட்காட்டியை இற்​றைப்படுத்துவதற்கு உங்களுக்கு அனுமதி இல்லை ",
"You do not have the permissions to delete this calendar." => "இந்த நாட்காட்டியை நீக்குவதற்கு உங்களுக்கு அனுமதி இல்லை ",
"You do not have the permissions to add to this calendar." => "இந்த நாட்காட்டியை சேர்ப்பதற்கு உங்களுக்கு அனுமதி இல்லை",
"You do not have the permissions to add events to this calendar." => "இந்த நாட்காட்டிக்கு நிகழ்வுகளை சேர்க்க உங்களுக்கு அனுமதி இல்லை",
"You do not have the permissions to delete this event." => "இந்த நிகழ்வை அழிப்பதற்கு உங்களுக்கு அனுமதி இல்லை ",
"Does not repeat" => "மீண்டும் இல்லாமல்",
"Daily" => "ஒவ்வொரு நாளும்",
"Weekly" => "வாரந்தோறும்",
"Every Weekday" => "ஒவ்வொரு வாரநாளும்",
"Bi-Weekly" => "இரு வாரத்திற்கு ஒரு முறை",
"Monthly" => "மாதந்தோரும்",
"Yearly" => "வருடந்தோறும்",
"never" => "ஒருபோதும்",
"by occurrences" => "நிகழ்வுகள் மூலம்",
"by date" => "திகதியினால்",
"by monthday" => "மாதநாளில்",
"by weekday" => "வாரநாளில்",
"events week of month" => "மாதத்தின் நிகழ்வு வாரங்கள்",
"first" => "முதலாவது",
"second" => "இரண்டாவது",
"third" => "மூன்றாவது",
"fourth" => "நான்காவது",
"fifth" => "ஐந்தாவது",
"last" => "இறுதி",
"by events date" => "நிகழ்வை கொண்ட திகதி",
"by yearday(s)" => "வருட நாள் (கள்) மூலம்",
"by weeknumber(s)" => "வார எண்ணிக்கை (கள்) மூலம்",
"by day and month" => "நாள் மற்றும் மாதம் மூலம்",
"Date" => "திகதி",
"Cal." => "Cal.",
"Week" => "வாரம்",
"Month" => "மாதம்",
"Today" => "இன்று",
"CalDav Link" => "CalDav இணைப்பு",
"Timezone" => "நேர மண்டலம்",
"Update timezone automatically" => "நேர மண்டலத்தை தன்னிச்சையாக இற்றைப்படுத்துக",
"Time format" => "நேர வடிவமைப்பு",
"24h" => "24ஆம்",
"12h" => "12ஆம்",
"Start week on" => "தொடங்கும் வாரம்",
"Cache" => "இடைமாற்றுநினைவகம்",
"Clear cache for repeating events" => "மீள் நிகழ்ச்சிக்கான இடைமாற்றுநினைவகத்தை சுத்தப்படுத்துக",
"Share Calendar" => "நாட்காட்டியை பகிர்க",
"Download" => "பதிவிறக்குக",
"Edit" => "தொகுக்க",
"Delete" => "அழிக்க",
"New calendar" => "புதிய நாட்காட்டி",
"Edit calendar" => "நாட்காட்டியை தொகுக்க",
"Eventinfo" => "நிகழ்வு தகவல்",
"Repeating" => "மீண்டும்",
"Alarm" => "எச்சரிக்கை",
"Attendees" => "பங்கேற்பாளர்கள்",
"Share" => "பகிர்வு",
"Title of the Event" => "நிகழ்வின் தலைப்பு",
"from" => "இலிருந்து",
"All Day Event" => "அனைத்து நாள் நிகழ்வு",
"Advanced options" => "மேலதிக தெரிவுகள்",
"Location" => "இடம்",
"Edit categories" => "வகைகளை தொகுக்க",
"Description" => "விவரணம்",
"Repeat" => "மீண்டும்",
"Advanced" => "உயர்ந்த",
"Select weekdays" => "வாரநாட்களை தெரிவுசெய்க",
"Select days" => "நாட்களை தெரிவுசெய்க",
"and the events day of year." => "வருடத்தில் நிகழ்வை கொண்ட நாட்கள்",
"and the events day of month." => "மாதத்தில் நிகழ்வை கொண்ட நாட்கள்",
"Select months" => "மாதங்களை தெரிவுசெய்க",
"Select weeks" => "வாரங்களை தெரிவுசெய்க",
"and the events week of year." => "வருடத்தில் நிகழ்வை கொண்ட வாரங்கள்",
"Interval" => "இடைவேளை",
"End" => "இறுதி",
"occurrences" => "நிகழ்ச்சி",
"create a new calendar" => "புதிய நாட்காட்டி ஒன்றை உருவாக்குக",
"Import a calendar file" => "நாட்காட்டி கோப்பொன்றை இறக்குமதி செய்க",
"Please choose a calendar" => "தயவுசெய்து ஒரு நாட்காட்டியை தெரிவுசெய்க",
"Name of new calendar" => "புதிய நாட்காட்டியின் பெயர்",
"Take an available name!" => "கிடைக்கக்கூடிய பெயரொன்றை எடுக்க!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "இந்த பெயரைக்கொண்ட நாட்காட்டி ஏற்கனவே உள்ளது.  நீங்கள் இதனை தொடர்ந்தால், நாட்காட்டிகள் ஒன்றிணைக்கப்படலாம். ",
"Remove all events from the selected calendar" => "தெரிவுசெய்யப்பட்ட நாட்காட்டியில் உள்ள எல்லா நிகழ்வுகளையும் அகற்றுக ",
"Import" => "இறக்குமதி",
"Close Dialog" => "Dialog மூடுக",
"Create a new event" => "புதிய நிகழ்வை உருவாக்க",
"Unshare" => "பகிரமுடியாது",
"Shared via calendar" => "நாட்காட்டியினூடாக பகிர்க",
"View an event" => "ஒரு நிகழ்வை பார்வையிடவும்",
"Category" => "வகை",
"No categories selected" => "வகைகள் தெரிவுசெய்யப்படவில்லை",
"From" => "இருந்து ",
"at" => "இல்",
"To" => "இற்கு"
);
